==> tmw-0.0.22.1.tar.gz: tmw-0.0.22.1/src/net/charserverhandler.h <==
/*
 *  The Mana World
 *  Copyright 2004 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: charserverhandler.h 2822 2006-11-05 14:30:53Z b_lindeijer $
 */

#ifndef _TMW_NET_CHARSERVERHANDLER_H
#define _TMW_NET_CHARSERVERHANDLER_H

#include "messagehandler.h"

#include "../lockedarray.h"

class LocalPlayer;
class LoginData;

class CharServerHandler : public MessageHandler
{
    public:
        CharServerHandler();

        void handleMessage(MessageIn *msg);

        void setCharInfo(LockedArray<LocalPlayer*> *charInfo) { mCharInfo = charInfo; };

        void setLoginData(LoginData *loginData) { mLoginData = loginData; };

    protected:
        LoginData *mLoginData;
        LockedArray<LocalPlayer*> *mCharInfo;

        LocalPlayer* readPlayerData(MessageIn *msg, int &slot);
};

#endif

==> tmw-0.0.27.tar.gz: tmw-0.0.27/src/net/charserverhandler.h <==
/*
 *  The Mana World
 *  Copyright 2004 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _TMW_NET_CHARSERVERHANDLER_H
#define _TMW_NET_CHARSERVERHANDLER_H

#include "messagehandler.h"

#include "../lockedarray.h"

class CharCreateDialog;
class LocalPlayer;
class LoginData;

/**
 * Deals with incoming messages from the character server.
 */
class CharServerHandler : public MessageHandler
{
    public:
        CharServerHandler();

        void handleMessage(MessageIn *msg);

        void setCharInfo(LockedArray<LocalPlayer*> *charInfo)
        { mCharInfo = charInfo; }

        void setLoginData(LoginData *loginData)
        { mLoginData = loginData; }

        /**
         * Sets the character create dialog. The handler will clean up this
         * dialog when a new character is succesfully created, and will unlock
         * the dialog when a new character failed to be created.
         */
        void setCharCreateDialog(CharCreateDialog *window)
        { mCharCreateDialog = window; }

    protected:
        LoginData *mLoginData;
        LockedArray<LocalPlayer*> *mCharInfo;
        CharCreateDialog *mCharCreateDialog;

        LocalPlayer* readPlayerData(MessageIn &msg, int &slot);
};

#endif
